/* 
 * Servo Control through joysticks - for excavator
 * 
 * Servo 9G wiring:
 *    Brown - GND
 *    Red - +5V
 *    Yellow - PWM
 */

#include <Servo.h>

#define Rt_Joy_X A2
#define Rt_Joy_Y A3
#define Rt_Joy_button 6
float Rt_Joy_X_val;
float Rt_Joy_Y_val;
float Rt_Joy_X_volts;
float Rt_Joy_Y_volts;

#define Lt_Joy_X A0
#define Lt_Joy_Y A1
#define Lt_Joy_button 7
float Lt_Joy_X_val;
float Lt_Joy_Y_val;
float Lt_Joy_X_volts;
float Lt_Joy_Y_volts;

/*
 * Create servo objects to control the servos
 * twelve servo objects can be created on most boards
 * 
 * Joy Sticks X-axes are aligned with pins
 * Joy sticks will be oriented in box so that pins face away from operator
 * 
 */
Servo PrimBoomServo;  // Left Joy X values
Servo CabServo;       // Left Joy Y values

Servo SecBoomServo;   // Right Joy X values
Servo BucketServo;    // Right Joy Y values

int PrBm_pos = 90;    // variable to store the servo position
int Cab_pos = 85;
int SecBm_pos = 90;
int Bkt_pos = 90;

//int PrBm_pos;    // variable to store the servo position
//int Cab_pos;
//int SecBm_pos;
//int Bkt_pos;

void setup() {
  /*
   * Initiating the servos: first number is pin the servo PWM is wired to
   * Next two numbers are the range of PWM duty cycle (min/max) that the servo recognizes
   * It is min/max pulse width in microseconds
   * Standard range is 544-2400
   * Jitter may be caused by getting PWM duty cycles the servo doesn't "like"
   */
  
  BucketServo.attach(5,1200,2400);     // attaches the servo on pin 5 to the servo object
  BucketServo.write(Bkt_pos);
  
  SecBoomServo.attach(6,750,2400);    // attaches the servo on pin 6 to the servo object
  SecBoomServo.write(SecBm_pos);
  
  PrimBoomServo.attach(9,1000,2400);   // attaches the servo on pin 9 to the servo object
  PrimBoomServo.write(PrBm_pos);
  
  CabServo.attach(10,1000,2400);       // attaches the servo on pin 10 to the servo object
  CabServo.write(Cab_pos);
  
  pinMode(Rt_Joy_X, INPUT);
  pinMode(Rt_Joy_Y, INPUT);
  pinMode(Rt_Joy_button, INPUT);
  pinMode(Lt_Joy_X, INPUT);
  pinMode(Lt_Joy_Y, INPUT);
  pinMode(Lt_Joy_button, INPUT);
  
  Serial.begin(9600);
}

void loop() {
  Rt_Joy_X_val = analogRead(Rt_Joy_X);
  Rt_Joy_Y_val = analogRead(Rt_Joy_Y);
  Lt_Joy_X_val = analogRead(Lt_Joy_X);
  Lt_Joy_Y_val = analogRead(Lt_Joy_Y);
  
  Rt_Joy_X_volts = Rt_Joy_X_val*5/1023;
  Rt_Joy_Y_volts = Rt_Joy_Y_val*5/1023;
  Lt_Joy_X_volts = Lt_Joy_X_val*5/1023;
  Lt_Joy_Y_volts = Lt_Joy_Y_val*5/1023;
  
//  Serial.print("   Rt_Joy_X_volts = ");
//  Serial.println(Rt_Joy_X_volts);
//  Serial.print("SecBm_Pos = ");
//  Serial.print(SecBm_pos);
  
//  Serial.print("  Rt_Joy_Y_volts = ");
//  Serial.println(Rt_Joy_Y_volts);
//  Serial.print("Bkt_Pos = ");
//  Serial.print(Bkt_pos);
  
//  Serial.print("   Lt_Joy_X_volts = ");
//  Serial.println(Lt_Joy_X_volts);
//  Serial.print("PrBm_Pos = ");
//  Serial.print(PrBm_pos);
  
//  Serial.print("  Lt_Joy_Y_volts = ");
//  Serial.println(Lt_Joy_Y_volts);
//  Serial.print("Cab_Pos = ");
//  Serial.print(Cab_pos);
  delay(10);
  
  /* 
   *  CONTROL FOR BUCKET
   */
  if (Rt_Joy_Y_volts < 2){
    Bkt_pos = Bkt_pos + 1;
    if (Bkt_pos > 160) {
      Bkt_pos = 160;
      }
    BucketServo.write(Bkt_pos);
    }
  
  if (Rt_Joy_Y_volts > 3.5){
    Bkt_pos = Bkt_pos - 1;
    if (Bkt_pos < 51) {
      Bkt_pos = 51;
      }
    BucketServo.write(Bkt_pos);
    }

  /*
   * CONTROL FOR SECONDARY BOOM
   */
  if (Rt_Joy_X_volts < 2){
    SecBm_pos = SecBm_pos + 2;
    if (SecBm_pos > 165) {
      SecBm_pos = 165;
      }
    SecBoomServo.write(SecBm_pos);
    }
  
  if (Rt_Joy_X_volts > 3.5){
    SecBm_pos = SecBm_pos - 2;
    if (SecBm_pos < 15) {
      SecBm_pos = 15;
      }
    SecBoomServo.write(SecBm_pos);
    }

  /*
   * CONTROL FOR PRIMARY BOOM UP/DOWN
   */
  if (Lt_Joy_X_volts > 3.5){
    PrBm_pos = PrBm_pos + 3;
    if (PrBm_pos > 165) {
      PrBm_pos = 165;
      }
    PrimBoomServo.write(PrBm_pos);
    }

  if (Lt_Joy_X_volts < 2){
    PrBm_pos = PrBm_pos - 3;
    if (PrBm_pos < 15) {
      PrBm_pos = 15;
      }
    PrimBoomServo.write(PrBm_pos);
    }

  /*
   * CONTROL FOR PRIMARY BOOM LEFT/RIGHT
   */
  if (Lt_Joy_Y_volts > 3.5){
    Cab_pos = Cab_pos + 3;
    if (Cab_pos > 165) {
      Cab_pos = 165;
      }
    CabServo.write(Cab_pos);
    }

  if (Lt_Joy_Y_volts < 2){
    Cab_pos = Cab_pos - 3;
    if (Cab_pos < 15) {
      Cab_pos = 15;
      }
    CabServo.write(Cab_pos);
    }
}
